After a model is fit with a specific lambda, use the output of the fitted parameters as initial values for the next lambda value, thus using warm starts at each successive lambda value.
mvregmed.grid.update(fit.obj, inits)A list with the same components as output from mvregmed.init
A fitted model of class mvregmed.
Initial values from mvregmed.init that are subsequently updated with new values from fit.obj
Daniel Schaid and Jason Sinnwell
Schaid DS, Dikilitas O, Sinnwell JP, Kullo I (2022). Penalized mediation models for multivariate data. Genet Epidemiol 46:32-50.
mvregmed.init