Create a lavaan model for input to lavan::sem()
regmed.lavaan.model(fit.edge, fit.regmed)a character string that descibes the mediation model in format of lavaan model
object created by regmed.edges function
object created by regmed.fit from which the fit.edge object was made
Dan Schaid, Greg Jenkins, Jason Sinnwell
The fit.regmed object is needed for the fixed covariance estimates to be put into the model statement. The summary method supersedes the default summary from the lavaan package to only return the table of coefficients, as the covariances are fixed from regmed.fit.