Assure that x, y, mediator are matrices, check column names and fill in if NULL, and reduce x, y, mediator so no missing values among all three matrices.
mvregmed.dat.check(x, y, mediator, max.cor=0.99)list with updated x, y, mediator
matrix with columns representing "exposure" variable (sometimes called instrumental variable)
matrix with columns representing outcome variables
matrix with columns representing mediator variables
maximum correlation within y, x, or mediators, so fitting is more robust
Daniel Schaid and Jason Sinnwell
mvregmed.fit
mvregmed.grid