regmed.lavaan.dat: Set up data to input to lavaan sem
Description
Set up data to input to lavaan structural equation model (sem)
Usage
regmed.lavaan.dat(x, mediator, y)
Value
A dataframe with updated x, mediator, and y
Arguments
- x
vector of exposure variables
- mediator
matrix of mediator variables
- y
vector of outcome variable
Author
Dan Schaid, Jason Sinnwell
Details
Use the function regmed.dat.check to standardize all variables and subset to subjects without missing data
References
Schaid, DJ, Sinnwell JP. (2020) Penalized Models for Analysis of
Multiple Mediators. Genet Epidemiol 44:408-424.